

import xlrd
import pymysql
from datetime import datetime

from crossborder.utils.db_helper import DBHelper
from crossborder.utils.parse_utils import convert_unit, parse_ratio


def get_upsert_sql():
    """生成带覆盖更新的SQL模板"""
    return """
    INSERT INTO `t_yujin_crossborder_monthly_summary` 
    (`year_month`, `monthly_total`, `monthly_import`, `monthly_export`, `trade_balance`,
     `ytd_total`, `ytd_import`, `ytd_export`, `ytd_trade_balance`, `create_time`)
    VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
    ON DUPLICATE KEY UPDATE
        monthly_total = VALUES(monthly_total),
        monthly_import = VALUES(monthly_import),
        monthly_export = VALUES(monthly_export),
        trade_balance = VALUES(trade_balance),
        ytd_total = VALUES(ytd_total),
        ytd_import = VALUES(ytd_import),
        ytd_export = VALUES(ytd_export),
        ytd_trade_balance = VALUES(ytd_trade_balance),
        create_time = VALUES(create_time)
    """


def parse_month_table_excel(file):
    db_helper = DBHelper()

    # 读取Excel文件
    try:
        workbook = xlrd.open_workbook(file)
        sheet = workbook.sheet_by_index(0)
    except Exception as e:
        print(f"文件读取失败: {e}")
        return

    sql = get_upsert_sql()
    current_time = datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    params_list = []

    for row_idx in range(5, sheet.nrows):
        base_row = sheet.row_values(row_idx)

        # 数据转换
        params = (
            base_row[1].replace('.', '-'),  # year_month
            convert_unit(base_row[2]),  # monthly_total
            convert_unit(base_row[4]),  # monthly_import
            convert_unit(base_row[3]),  # monthly_export
            convert_unit(base_row[5]),  # trade_balance
            convert_unit(base_row[6]),  # ytd_total
            parse_ratio(base_row[7]),  # ytd_import
            parse_ratio(base_row[8]),  # ytd_export
            parse_ratio(base_row[9]),  # ytd_balance
            current_time  # create_time
        )

        params_list.append(params)

    # 使用 DBHelper 执行 SQL 插入
    try:
        affected_rows = db_helper.execute_sql_with_params(sql, params_list)
        print(f"成功处理 {len(params_list)} 条数据，受影响行数：{affected_rows}")
    except Exception as e:
        print(f"数据库操作失败: {e}")
if __name__ == "__main__":
    parse_month_table_excel(f"/downloads/total/2025/03/(1)2025年进出口商品总值表 B-月度表.xls")